@@ -2,8 +2,8 @@
  *
  * CHECKS.C - Service and host check functions for Nagios
  *
- * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   06-20-2006
+ * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   04-10-2006
  *
  * License:
  *
@@ -271,7 +271,7 @@ void run_service_check(service *svc){
 	/* send data to event broker */
 	end_time.tv_sec=0L;
 	end_time.tv_usec=0L;
-	broker_service_check(NEBTYPE_SERVICECHECK_INITIATE,NEBFLAG_NONE,NEBATTR_NONE,svc,SERVICE_CHECK_ACTIVE,start_time,end_time,svc->service_check_command,svc->latency,0.0,0,FALSE,0,processed_command,NULL);
+	broker_service_check(NEBTYPE_SERVICECHECK_INITIATE,NEBFLAG_NONE,NEBATTR_NONE,svc,SERVICE_CHECK_ACTIVE,start_time,end_time,svc->service_check_command,svc->latency,0.0,service_check_timeout,FALSE,0,processed_command,NULL);
 #endif
 
 #ifdef EMBEDDEDPERL
@@ -523,6 +523,15 @@ void run_service_check(service *svc){
 				svc_msg.exited_ok=FALSE;
 				svc_msg.early_timeout=FALSE;
 			        }
+			else if(WEXITSTATUS(pclose_result)==0 && WIFSIGNALED(pclose_result)){
+				snprintf(svc_msg.output,sizeof(svc_msg.output)-1,"(Plugin received signal %d!)\n",WTERMSIG(pclose_result));
+				svc_msg.output[sizeof(svc_msg.output)-1]='\x0';
+				svc_msg.exited_ok=TRUE;
+				svc_msg.early_timeout=FALSE;
+				/* like bash */
+				pclose_result=128+WTERMSIG(pclose_result);
+				svc_msg.return_code=pclose_result;
+				}
 
 			/* write check result to message queue */
 			write_svc_message(&svc_msg);
@@ -2055,7 +2064,7 @@ int check_host(host *hst, int propagation_options, int check_options){
 	/* send data to event broker */
 	end_time.tv_sec=0L;
 	end_time.tv_usec=0L;
-	broker_host_check(NEBTYPE_HOSTCHECK_INITIATE,NEBFLAG_NONE,NEBATTR_NONE,hst,HOST_CHECK_ACTIVE,hst->current_state,hst->state_type,start_time,end_time,hst->host_check_command,hst->latency,0.0,0,FALSE,0,NULL,NULL,NULL,NULL);
+	broker_host_check(NEBTYPE_HOSTCHECK_INITIATE,NEBFLAG_NONE,NEBATTR_NONE,hst,HOST_CHECK_ACTIVE,hst->current_state,hst->state_type,start_time,end_time,hst->host_check_command,hst->latency,0.0,host_check_timeout,FALSE,0,NULL,NULL,NULL,NULL);
 #endif
 
 	/* make sure we return the original host state unless it changes... */
@@ -2098,8 +2107,9 @@ int check_host(host *hst, int propagation_options, int check_options){
 			if(sigrestart==TRUE || sigshutdown==TRUE){
 				hst->current_attempt=1;
 				hst->current_state=old_state;
-				free(hst->plugin_output);
-				hst->plugin_output=(char *)old_plugin_output;
+				if(hst->plugin_output!=NULL)
+					free(hst->plugin_output);
+				hst->plugin_output=(char *)strdup(old_plugin_output);
 				return hst->current_state;
 				}
 
@@ -2194,8 +2204,9 @@ int check_host(host *hst, int propagation_options, int check_options){
 			if(sigrestart==TRUE || sigshutdown==TRUE){
 				hst->current_attempt=1;
 				hst->current_state=old_state;
-				free(hst->plugin_output);
-				hst->plugin_output=(char *)old_plugin_output;
+				if(hst->plugin_output!=NULL)
+					free(hst->plugin_output);
+				hst->plugin_output=(char *)strdup(old_plugin_output);
 				return hst->current_state;
 				}
 
@@ -2422,7 +2433,7 @@ int run_host_check(host *hst, int check_options){
 		printf("\tNo host check command specified, so no check will be done (host state assumed to be unchanged)!\n");
 #endif
 
-		return HOST_UP;
+		return hst->current_state;
 	        }
 
 	/* grab the host macros */
