@@ -2,8 +2,8 @@
  *
  * CGIUTILS.C - Common utilities for Nagios CGIs
  * 
- * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 05-20-2006
+ * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 04-10-2007
  *
  * License:
  *
@@ -1366,8 +1366,9 @@ char * html_encode(char *input){
 			y++;
 		        }
 
+#ifdef NOT_SO_SURE_ABOUT_THIS
 		/* spaces are encoded as non-breaking spaces */
-		else if((char)input[x]<=(char)' '){
+		else if((char)input[x]==(char)' '){
 
 			encoded_html_string[y]='\x0';
 			if((int)strlen(encoded_html_string)<(output_len-6)){
@@ -1375,6 +1376,25 @@ char * html_encode(char *input){
 				y+=6;
 			        }
 		        }
+#endif
+
+		else if((char)input[x]==(char)'<'){
+
+			encoded_html_string[y]='\x0';
+			if((int)strlen(encoded_html_string)<(output_len-4)){
+				strcat(encoded_html_string,"&lt;");
+				y+=4;
+			        }
+		        }
+
+		else if((char)input[x]==(char)'>'){
+
+			encoded_html_string[y]='\x0';
+			if((int)strlen(encoded_html_string)<(output_len-4)){
+				strcat(encoded_html_string,"&gt;");
+				y+=4;
+			        }
+		        }
 
 		/* for simplicity, everything else gets represented by its numeric value */
 		else{
@@ -1394,6 +1414,16 @@ char * html_encode(char *input){
 
 
 
+/* strips dangerous HTML from plugin output */
+char * strip_plugin_html(char *input){
+
+	/* TODO */
+
+	return input;
+	}
+
+
+
 /* determines the log file we should use (from current time) */
 void get_log_archive_to_use(int archive,char *buffer,int buffer_length){
 	struct tm *t;
@@ -1561,7 +1591,7 @@ void display_info_table(char *title,int refresh, authdata *current_authdata){
 	int result;
 
 	/* read program status */
-	result=read_all_status_data(DEFAULT_CGI_CONFIG_FILE,READ_PROGRAM_STATUS);
+	result=read_all_status_data(get_cgi_config_location(),READ_PROGRAM_STATUS);
 
 	printf("<TABLE CLASS='infoBox' BORDER=1 CELLSPACING=0 CELLPADDING=0>\n");
 	printf("<TR><TD CLASS='infoBox'>\n");
